/**
 * This file is part of pppBenchmark, a program accompanying
 * the paper: Abeel, T, Van de Peer Y, Saeys Y.  2009.  Towards a gold standard for promoter prediction evaluation. Bioinformatics. 25(12):i313-i320.
    * 
 * Copyright 2009 Thomas Abeel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 */
package be.abeel.pppbenchmark;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.zip.GZIPInputStream;

import be.abeel.io.ColumnIterator;

public class Config {

	public static String[] chrs = { "chr1", "chr2", "chr3", "chr4", "chr5", "chr6", "chr7", "chr8", "chr9", "chr10", "chr11", "chr12", "chr13", "chr14", "chr15", "chr16", "chr17", "chr18", "chr19", "chr20", "chr21", "chr22", "chrx", "chry" };
//	public static String[] chrs = { "chr21", "chr22"};
	static Map<String, Long> chrSize = new HashMap<String, Long>();
	static {
		ColumnIterator it = new ColumnIterator(Config.class.getResourceAsStream("/data/chromosomesize.txt"));
		for (String[] arr : it) {
			chrSize.put(arr[0].toLowerCase(), Long.parseLong(arr[1]));
		}
	}
	public static int distance = 500;

	public static double steps = 500.0;
	private static File tags;
	private static File gene;

	public static void setTags(File f) {
		Config.tags = f;
		System.out.println("Config tags="+tags);
		System.out.println("Config gene="+gene);
	}

	public static void setGene(File f) {
		Config.gene = f;
	}

	public static InputStream cage() throws IOException {
		
		if (tags != null)
			return new FileInputStream(tags);
		return new GZIPInputStream(Config.class.getResourceAsStream("/data/cage_hg18.1.gff.gz"));
	}

	public static InputStream gene() throws IOException {
		
		if(gene!=null)
			return new FileInputStream(gene);
		return new GZIPInputStream(Config.class.getResourceAsStream("/data/ucscRefseq.bed.gz"));
	}
}
